
========
plothist
========

**Plot histograms in a scalable way and a beautiful style.**

* Installation and documentation: `https://plothist.readthedocs.io/ <https://plothist.readthedocs.io/>`_
* Image gallery: `https://plothist.readthedocs.io/en/latest/example_gallery/ <https://plothist.readthedocs.io/en/latest/example_gallery/>`_

|img1| |img2|

.. |img1| image:: https://raw.githubusercontent.com/cyrraz/plothist/main/docs/img/1d_comparison_advanced.svg
   :alt: Example
   :width: 320

.. |img2| image:: https://raw.githubusercontent.com/cyrraz/plothist/main/docs/img/model_examples_stacked.svg
   :alt: Example
   :width: 320


|GitHub Project| |PyPI version| |Docs from latest| |Docs from main| |Code style: black|


**Major advantages over other plotting libraries**: scalability, style and user-friendly way of managing variables and a stunning `image gallery <https://plothist.readthedocs.io/en/latest/example_gallery/>`_.

1. **First idea**: default style is already presentation-ready and/or paper-ready (with no effort).

2. **Second idea**: separate the histogram creation from its plotting. Then you can easily manage histogram objects (``boost_histogram`` `library <https://boost-histogram.readthedocs.io/>`_) and plot large amount of variables and data really fast.

3. **Third idea**: plot a lot of variable easily with a variable manager. Really easy to modify the plotting information and do multiple plots with same variable but different settings.

4. **Fourth idea**: detailed and user-friendly documentation including a marvelous `gallery of examples <https://plothist.readthedocs.io/en/latest/example_gallery/>`_.



.. image:: https://raw.githubusercontent.com/cyrraz/plothist/main/docs/img/2d_hist_with_projections.svg
   :alt: 2D histogram with projections
   :width: 500
   :align: center



.. |GitHub Project| image:: https://img.shields.io/badge/GitHub--blue?style=social&logo=GitHub
   :target: https://github.com/cyrraz/plothist
.. |PyPI version| image:: https://badge.fury.io/py/plothist.svg
   :target: https://badge.fury.io/py/plothist
.. |Code style: black| image:: https://img.shields.io/badge/code%20style-black-000000.svg
   :target: https://github.com/psf/black
.. |Docs from latest| image:: https://img.shields.io/badge/docs-v1.0.3-blue.svg
   :target: https://plothist.readthedocs.io/en/latest/
.. |Docs from main| image:: https://img.shields.io/badge/docs-main-blue.svg
   :target: https://plothist.readthedocs.io/en/main/
